Module axis_angle

Module axis_angle 

Functions

axis_angle_from_quaternionDeprecated
free_axis_angles_memoryDeprecated
new_axis_angleDeprecated
viam_axis_angle_from_quaternion
Converts a quaternion into an R4 axis angle. The return value is a pointer to a list of [x, y, x, theta], where (x,y,z) are the axis vector components and theta is the rotation about the axis in radians. A zero quaternion returns a zero axis angle. In the event of an error from the nalgebra crate, a zero axis angle is also returned.
viam_free_axis_angles_memory
Free memory at the address of the axis angle pointer.
viam_new_axis_angle
Initialize axis angle from raw components and retrieve the C pointer to its address.