#[no_mangle]
pub unsafe extern "C" fn normalize_vector(vec_ptr: *mut Vector3<f64>)
Normalizes an existing vector stored at the address of a pointer (vec_ptr)

Safety

When finished with the underlying vector, the caller must remember to free the vector memory using the free_vector_memory FFI function