#[repr(i32)]
pub enum ClientLibraryOrganization {
    Unspecified,
    Cloud,
    Ads,
    Photos,
    StreetView,
}
The organization for which the client libraries are being published. Affects the url where generated docs are published, etc.

Variants



Unspecified

Not useful.



Cloud

Google Cloud Platform Org.



Ads

Ads (Advertising) Org.



Photos

Photos Org.



StreetView

Street View Org.

Implementations

source

impl ClientLibraryOrganization

source

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ClientLibraryOrganization.

source

pub fn from_i32(value: i32) -> Option<ClientLibraryOrganization>

Converts an i32 to a ClientLibraryOrganization, or None if value is not a valid variant.