Struct viam_rust_utils::gen::google::api::method_settings::LongRunning
source · pub struct LongRunning {
pub initial_poll_delay: Option<Duration>,
pub poll_delay_multiplier: f32,
pub max_poll_delay: Option<Duration>,
pub total_poll_timeout: Option<Duration>,
}Expand description
Describes settings to use when generating API methods that use the long-running operation pattern. All default values below are from those used in the client library generators (e.g. [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
Fields
initial_poll_delay: Option<Duration>Initial delay after which the first poll request will be made. Default value: 5 seconds.
poll_delay_multiplier: f32Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay. Default value: 1.5.
max_poll_delay: Option<Duration>Maximum time between two subsequent poll requests. Default value: 45 seconds.
total_poll_timeout: Option<Duration>Total polling timeout. Default value: 5 minutes.