Struct viam_rust_utils::gen::google::api::ClientLibrarySettings
source · pub struct ClientLibrarySettings {
pub version: String,
pub launch_stage: i32,
pub rest_numeric_enums: bool,
pub java_settings: Option<JavaSettings>,
pub cpp_settings: Option<CppSettings>,
pub php_settings: Option<PhpSettings>,
pub python_settings: Option<PythonSettings>,
pub node_settings: Option<NodeSettings>,
pub dotnet_settings: Option<DotnetSettings>,
pub ruby_settings: Option<RubySettings>,
pub go_settings: Option<GoSettings>,
}Expand description
Details about how and where to publish client libraries.
Fields
version: StringVersion of the API to apply these settings to.
launch_stage: i32Launch stage of this version of the API.
rest_numeric_enums: boolWhen using transport=rest, the client request will encode enums as numbers rather than strings.
java_settings: Option<JavaSettings>Settings for legacy Java features, supported in the Service YAML.
cpp_settings: Option<CppSettings>Settings for C++ client libraries.
php_settings: Option<PhpSettings>Settings for PHP client libraries.
python_settings: Option<PythonSettings>Settings for Python client libraries.
node_settings: Option<NodeSettings>Settings for Node client libraries.
dotnet_settings: Option<DotnetSettings>Settings for .NET client libraries.
ruby_settings: Option<RubySettings>Settings for Ruby client libraries.
go_settings: Option<GoSettings>Settings for Go client libraries.
Implementations
sourceimpl ClientLibrarySettings
impl ClientLibrarySettings
sourcepub fn launch_stage(&self) -> LaunchStage
pub fn launch_stage(&self) -> LaunchStage
Returns the enum value of launch_stage, or the default if the field is set to an invalid enum value.
sourcepub fn set_launch_stage(&mut self, value: LaunchStage)
pub fn set_launch_stage(&mut self, value: LaunchStage)
Sets launch_stage to the provided enum value.