pub struct GoSettings {
pub common: Option<CommonLanguageSettings>,
pub renamed_services: HashMap<String, String>,
}Expand description
Settings for Go client libraries.
Fields
common: Option<CommonLanguageSettings>Some settings.
renamed_services: HashMap<String, String>Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options.
publishing: go_settings: renamed_services: Publisher: TopicAdmin