pub struct SelectiveGapicGeneration {
pub methods: Vec<String>,
pub generate_omitted_as_internal: bool,
}Expand description
This message is used to configure the generation of a subset of the RPCs in a service for client libraries.
Fields
methods: Vec<String>An allowlist of the fully qualified names of RPCs that should be included on public client surfaces.
generate_omitted_as_internal: boolSetting this to true indicates to the client generators that methods that would be excluded from the generation should instead be generated in a way that indicates these methods should not be consumed by end users. How this is expressed is up to individual language implementations to decide. Some examples may be: added annotations, obfuscated identifiers, or other language idiomatic patterns.