pub struct ErrorInfo {
pub reason: String,
pub domain: String,
pub metadata: HashMap<String, String>,
}Expand description
Describes the cause of the error with structured details.
Example of an error when contacting the “pubsub.googleapis.com” API when it is not enabled:
{ "reason": "API_DISABLED"
"domain": "googleapis.com"
"metadata": {
"resource": "projects/123",
"service": "pubsub.googleapis.com"
}
}This response indicates that the pubsub.googleapis.com API is not enabled.
Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock:
{ "reason": "STOCKOUT"
"domain": "spanner.googleapis.com",
"metadata": {
"availableRegions": "us-central1,us-east2"
}
}Fields
reason: StringThe reason of the error. This is a constant value that identifies the
proximate cause of the error. Error reasons are unique within a particular
domain of errors. This should be at most 63 characters and match a
regular expression of \[A-Z][A-Z0-9_]+[A-Z0-9\], which represents
UPPER_SNAKE_CASE.
domain: StringThe logical grouping to which the “reason” belongs. The error domain is typically the registered service name of the tool or product that generates the error. Example: “pubsub.googleapis.com”. If the error is generated by some common infrastructure, the error domain must be a globally unique value that identifies the infrastructure. For Google API infrastructure, the error domain is “googleapis.com”.
metadata: HashMap<String, String>Additional structured details about this error.
Keys must match a regular expression of \[a-z][a-zA-Z0-9-_\]+ but should
ideally be lowerCamelCase. Also, they must be limited to 64 characters in
length. When identifying the current value of an exceeded limit, the units
should be contained in the key, not the value. For example, rather than
{"instanceLimit": "100/request"}, should be returned as,
{"instanceLimitPerRequest": "100"}, if the client exceeds the number of
instances that can be created in a single (batch) request.