pub struct PreconditionFailure {
pub violations: Vec<Violation>,
}Expand description
Describes what preconditions have failed.
For example, if an RPC failed because it required the Terms of Service to be acknowledged, it could list the terms of service violation in the PreconditionFailure message.
Fields
violations: Vec<Violation>Describes all precondition violations.