Functions
- axis_
angle_ ⚠from_ quaternion Deprecated - free_
axis_ ⚠angles_ memory Deprecated - new_
axis_ angle Deprecated - viam_
axis_ ⚠angle_ from_ quaternion - Converts a quaternion into an R4 axis angle. The return value is a pointer to a list of [x, y, x, theta], where (x,y,z) are the axis vector components and theta is the rotation about the axis in radians. A zero quaternion returns a zero axis angle. In the event of an error from the nalgebra crate, a zero axis angle is also returned.
- viam_
free_ ⚠axis_ angles_ memory - Free memory at the address of the axis angle pointer.
- viam_
new_ axis_ angle - Initialize axis angle from raw components and retrieve the C pointer to its address.