Function viam_rust_utils::ffi::spatialmath::vector3::scale_vector
source · #[no_mangle]
pub unsafe extern "C" fn scale_vector(
vec_ptr: *mut Vector3<f64>,
factor: f64
)Expand description
Scales an existing vector stored at the address of a pointer (vec_ptr) by a float factor
Safety
When finished with the underlying vector, the caller must remember to free the vector memory using the free_vector_memory FFI function