Function viam_rust_utils::ffi::spatialmath::vector3::vector_get_components
source · #[no_mangle]
pub unsafe extern "C" fn vector_get_components(
vec_ptr: *const Vector3<f64>
) -> *const c_doubleExpand description
Get the components of a vector as a list of C doubles, the order of the components will be (x, y, z).
Safety
When finished with the underlying vector, the caller must remember to free the vector memory using the free_vector_memory FFI function