Function viam_rust_utils::ffi::spatialmath::vector3::vector_get_normalized
source · #[no_mangle]
pub unsafe extern "C" fn vector_get_normalized(
vec_ptr: *const Vector3<f64>
) -> *mut Vector3<f64>Expand description
Initializes a normalized copy of a vector stored at the address of a pointer (vec_ptr) and returns a pointer to the memory of the result
Safety
The caller must remember to free the vector memory of both the input and output vectors when finished with them using the free_vector_memory FFI function