pub enum Pattern {
Get(String),
Put(String),
Post(String),
Delete(String),
Patch(String),
Custom(CustomHttpPattern),
}Expand description
Determines the URL pattern is matched by this rules. This pattern can be used with any of the {get|put|post|delete|patch} methods. A custom method can be defined using the ‘custom’ field.
Variants
Get(String)
Maps to HTTP GET. Used for listing and getting information about resources.
Put(String)
Maps to HTTP PUT. Used for replacing a resource.
Post(String)
Maps to HTTP POST. Used for creating a resource or performing an action.
Delete(String)
Maps to HTTP DELETE. Used for deleting a resource.
Patch(String)
Maps to HTTP PATCH. Used for updating a resource.
Custom(CustomHttpPattern)
The custom pattern is used for specifying an HTTP method that is not
included in the pattern field, such as HEAD, or “*” to leave the
HTTP method unspecified for this rule. The wild-card rule is useful
for services that provide content to Web (HTML) clients.
Implementations