pub struct BatchingSettingsProto {
pub element_count_threshold: i32,
pub request_byte_threshold: i64,
pub delay_threshold: Option<Duration>,
pub element_count_limit: i32,
pub request_byte_limit: i32,
pub flow_control_element_limit: i32,
pub flow_control_byte_limit: i32,
pub flow_control_limit_exceeded_behavior: i32,
}Expand description
BatchingSettingsProto specifies a set of batching thresholds, each of
which acts as a trigger to send a batch of messages as a request. At least
one threshold must be positive nonzero.
Fields
element_count_threshold: i32The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
request_byte_threshold: i64The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message.
delay_threshold: Option<Duration>The duration after which a batch should be sent, starting from the addition of the first message to that batch.
element_count_limit: i32The maximum number of elements collected in a batch that could be accepted by server.
request_byte_limit: i32The maximum size of the request that could be accepted by server.
flow_control_element_limit: i32The maximum number of elements allowed by flow control.
flow_control_byte_limit: i32The maximum size of data allowed by flow control.
flow_control_limit_exceeded_behavior: i32The behavior to take when the flow control limit is exceeded.
Implementations
Sourceimpl BatchingSettingsProto
impl BatchingSettingsProto
Sourcepub fn flow_control_limit_exceeded_behavior(
&self,
) -> FlowControlLimitExceededBehaviorProto
pub fn flow_control_limit_exceeded_behavior( &self, ) -> FlowControlLimitExceededBehaviorProto
Returns the enum value of flow_control_limit_exceeded_behavior, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flow_control_limit_exceeded_behavior(
&mut self,
value: FlowControlLimitExceededBehaviorProto,
)
pub fn set_flow_control_limit_exceeded_behavior( &mut self, value: FlowControlLimitExceededBehaviorProto, )
Sets flow_control_limit_exceeded_behavior to the provided enum value.